from urllib.parse import urljoin

import requests


class RequestHelper(requests.Session):
    def __init__(self, base_url: str, request_id: str = None):
        super().__init__()
        self.base_url = base_url
        self.headers['request-id'] = request_id

    def request(self, method, url, *args, **kwargs):
        joined_url = urljoin(self.base_url, url)
        return super().request(method, joined_url, *args, **kwargs)



import logging

from influxdb_influxql_client.client._base import _BaseClient
from influxdb_influxql_client.client.query_api import QueryApi

logger = logging.getLogger('influxdb_client.client.influxdb_client')


class InfluxQLClient(_BaseClient):
    def __init__(self, base_url, database):
        super().__init__(base_url, database)

    def query_api(self) -> QueryApi:
        return QueryApi(self)



from influxdb_influxql_client.client.util.request_helper import RequestHelper


class _BaseClient(object):
    def __init__(self, base_url, database):
        self.url = base_url
        self.database = database
        self.sh = RequestHelper(base_url)



from typing import List, Optional, Any, Dict

from pydantic import BaseModel


class SeriesModel(BaseModel):
    name: str
    columns: List[str]
    values: List[List[Any]]
    tags: Optional[Dict[str, str]]


class ResultModel(BaseModel):
    statement_id: int
    series: Optional[List[SeriesModel]]
    error: Optional[str]


class ResultsModel(BaseModel):
    results: List[ResultModel]



import requests

from influxdb_influxql_client.client.models.Results import ResultsModel


class QueryApi:
    def __init__(self, influxdb_client):
        self._influxdb_client = influxdb_client

    def _query(self, query: str):
        response: requests.Response = self._influxdb_client.sh.get("query", params={
            'q': query,
            'db': self._influxdb_client.database
        })

        assert response.status_code == 200
        return response

    def query(self, query: str) -> ResultsModel:
        response = self._query(query)

        results = ResultsModel(**response.json())

        return results

    def query_raw(self, query: str):
        return self._query(query).content



import json
import unittest
from unittest import mock

from influxdb_influxql_client import InfluxQLClient


def mocked_requests_get(*args, **kwargs):
    class MockResponse:
        def __init__(self, json_data, status_code):
            self.json_data = json_data
            self.status_code = status_code

        def json(self):
            return self.json_data

    if str(args[0]).startswith('select 1'):
        with open('./mocked_responses/happy_cpu_metrics.json') as f:
            d = json.load(f)
        return MockResponse(d, 200)

    return MockResponse(None, 404)


class BasicTest(unittest.TestCase):

    @mock.patch('influxdb_influxql_client.client.query_api.QueryApi._query', side_effect=mocked_requests_get)
    def test_fetch(self, mock_get):
        ic = InfluxQLClient('http://mocked.local:8086', 'database')
        results = ic.query_api().query("select 1")

        assert len(results.results) == 1
        assert len(results.results[0].series) == 1
        assert 'time' in results.results[0].series[0].columns
        assert 'mean' in results.results[0].series[0].columns
        assert results.results[0].series[0].name == "cpu"
        assert len(results.results[0].series[0].values) == 1801


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages  # noqa: H301

requires = [
    'setuptools >= 21.0.0',
    'requests >= 2.28.2',
    'pydantic'
]

readme = open('README.md').read()

NAME = "influxql_client"

setup(
    name=NAME,
    version='0.0.2',
    description="InfluxDB InfluxQL Basic Library",
    keywords=["InfluxDB", "InfluxDB Python Client", "InfluxQL"],
    long_description=readme,
    long_description_content_type="text/markdown",
    install_requires=requires,
    packages=find_packages(exclude=('tests*',)),
    test_suite='tests',
    python_requires='>=3.7',
    include_package_data=True,
    url="https://github.com/delrey1/influxdb-influxql-client",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ])
